==> jboss-ewp-src-5.1.0.zip: jboss-ewp-5.1-src/seam/src/main/org/jboss/seam/security/permission/EntityIdentifierStrategy.java <==
package org.jboss.seam.security.permission;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import javax.persistence.Entity;
import javax.persistence.EntityManager;

import org.jboss.seam.Component;
import org.jboss.seam.Seam;
import org.jboss.seam.annotations.security.permission.Identifier;
import org.jboss.seam.core.Expressions;
import org.jboss.seam.core.Expressions.ValueExpression;
import org.jboss.seam.persistence.PersistenceProvider;
import org.jboss.seam.util.Strings;

/**
 * An Identifier strategy for entity-based permission checks
 * 
 * @author Shane Bryzak
 */
public class EntityIdentifierStrategy implements IdentifierStrategy
{
   private ValueExpression<EntityManager> entityManager;   
   
   private PersistenceProvider persistenceProvider;
   
   private Map<Class,String> identifierNames = new ConcurrentHashMap<Class,String>();
   
   public EntityIdentifierStrategy()
   {
      persistenceProvider = (PersistenceProvider) Component.getInstance(PersistenceProvider.class, true);
      
      if (entityManager == null)
      {
         entityManager = Expressions.instance().createValueExpression("#{entityManager}", 
               EntityManager.class);
      }         
   }
   
   public boolean canIdentify(Class targetClass)
   {
      return targetClass.isAnnotationPresent(Entity.class);
   }

   public String getIdentifier(Object target)
   {
      Object persProviderId = persistenceProvider.getId(target, lookupEntityManager());
      return String.format("%s:%s", getIdentifierName(target.getClass()), persProviderId);
   }
   
   private String getIdentifierName(Class cls)
   {
      if (!identifierNames.containsKey(cls))
      {   
         String name = null;
         
         if (cls.isAnnotationPresent(Identifier.class))
         {
            Identifier identifier = (Identifier) cls.getAnnotation(Identifier.class);
            if ( !Strings.isEmpty(identifier.name()) )
            {
               name = identifier.name();
            }
         }
         
         if (name == null)
         {
            name = Seam.getComponentName(cls);
         }
         
         if (name == null)
         {
            name = cls.getName().substring(cls.getName().lastIndexOf('.') + 1);
         }
         
         identifierNames.put(cls, name);
         return name;
      }
      
      return identifierNames.get(cls);
   }

   private EntityManager lookupEntityManager()
   {
      return entityManager.getValue();
   }
}

==> jboss-ewp-src-5.2.0.zip: jboss-ewp-5.2-src/seam/src/main/org/jboss/seam/security/permission/EntityIdentifierStrategy.java <==
package org.jboss.seam.security.permission;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import javax.persistence.Entity;
import javax.persistence.EntityManager;

import org.jboss.seam.Component;
import org.jboss.seam.Seam;
import org.jboss.seam.annotations.security.permission.Identifier;
import org.jboss.seam.core.Expressions;
import org.jboss.seam.core.Expressions.ValueExpression;
import org.jboss.seam.persistence.PersistenceProvider;
import org.jboss.seam.util.Strings;

/**
 * An Identifier strategy for entity-based permission checks
 * 
 * @author Shane Bryzak
 */
public class EntityIdentifierStrategy implements IdentifierStrategy, java.io.Serializable
{
   private transient ValueExpression<EntityManager> entityManager;   
   
   private transient PersistenceProvider persistenceProvider;
   
   private Map<Class,String> identifierNames = new ConcurrentHashMap<Class,String>();
   
	public void init()
	{
		if (persistenceProvider == null)
		{
			persistenceProvider = (PersistenceProvider) Component.getInstance(PersistenceProvider.class, true);
		}

	    if (entityManager == null)
	    {
	    	entityManager = Expressions.instance().createValueExpression("#{entityManager}", EntityManager.class);
	    }
		
	}

   public EntityIdentifierStrategy()
   {
      init();  
   }
   
   public boolean canIdentify(Class targetClass)
   {
      return targetClass.isAnnotationPresent(Entity.class);
   }

   public String getIdentifier(Object target)
   {
	  if(persistenceProvider == null) init();
      Object persProviderId = persistenceProvider.getId(target, lookupEntityManager());
      return String.format("%s:%s", getIdentifierName(target.getClass()), persProviderId);
   }
   
   private String getIdentifierName(Class cls)
   {
      if (!identifierNames.containsKey(cls))
      {   
         String name = null;
         
         if (cls.isAnnotationPresent(Identifier.class))
         {
            Identifier identifier = (Identifier) cls.getAnnotation(Identifier.class);
            if ( !Strings.isEmpty(identifier.name()) )
            {
               name = identifier.name();
            }
         }
         
         if (name == null)
         {
            name = Seam.getComponentName(cls);
         }
         
         if (name == null)
         {
            name = cls.getName().substring(cls.getName().lastIndexOf('.') + 1);
         }
         
         identifierNames.put(cls, name);
         return name;
      }
      
      return identifierNames.get(cls);
   }

   private EntityManager lookupEntityManager()
   {
	  if(entityManager == null) init();
      return entityManager.getValue();
   }
}
